@@ -1,33 +1,35 @@
 bundles <-
-function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE, 
+function (x, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE, 
     collapse = FALSE) 
 {
-    ifelse(isTRUE(is.null(dimnames(m)[1]) == TRUE | is.null(dimnames(m)[1][[1]]) == 
-        TRUE) == TRUE, LBS <- 1:nrow(m), LBS <- dimnames(m)[[1]])
+    if (is.array(x) == FALSE) 
+        stop("'x' must be an array.")
+    ifelse(isTRUE(is.null(dimnames(x)[1]) == TRUE | is.null(dimnames(x)[1][[1]]) == 
+        TRUE) == TRUE, LBS <- 1:nrow(x), LBS <- dimnames(x)[[1]])
     lbs <- seq(LBS)
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
-        if (isTRUE(is.null(dimnames(m)[[3]]) == TRUE) | isTRUE(any(duplicated(dimnames(m)[[3]]))) == 
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
+        if (isTRUE(is.null(dimnames(x)[[3]]) == TRUE) | isTRUE(any(duplicated(dimnames(x)[[3]]))) == 
             TRUE) 
-            dimnames(m)[[3]] <- 1:dim(m)[3]
+            dimnames(x)[[3]] <- 1:dim(x)[3]
     }
-    if (is.na(dim(m)[3]) == FALSE) {
-        x <- transf(dichot(m)[, , 1], "matlist", labels = lbs, 
+    if (is.na(dim(x)[3]) == FALSE) {
+        m <- transf(dichot(x)[, , 1], type = "matlist", labels = lbs, 
             prsep = prsep, lb2lb = lb2lb)
-        if (isTRUE(dim(m)[3] > 1) == TRUE) {
-            for (k in 2:dim(m)[3]) x <- append(x, transf(dichot(m)[, 
-                , k], "matlist", labels = lbs, prsep = prsep, 
+        if (isTRUE(dim(x)[3] > 1L) == TRUE) {
+            for (k in 2:dim(x)[3]) m <- append(m, transf(dichot(x)[, 
+                , k], type = "matlist", labels = lbs, prsep = prsep, 
                 lb2lb = lb2lb))
             rm(k)
         }
     }
     else {
-        x <- transf(dichot(m), "matlist", labels = lbs, prsep = prsep, 
-            lb2lb = lb2lb)
+        m <- transf(dichot(x), type = "matlist", labels = lbs, 
+            prsep = prsep, lb2lb = lb2lb)
     }
     dfl <- data.frame(matrix(ncol = 2L, nrow = 0L))
-    for (i in 1:length(x)) {
-        dfl[i, 1] <- strsplit(x[i], prsep)[[1]][1]
-        dfl[i, 2] <- strsplit(x[i], prsep)[[1]][2]
+    for (i in 1:length(m)) {
+        dfl[i, 1] <- strsplit(m[i], prsep)[[1]][1]
+        dfl[i, 2] <- strsplit(m[i], prsep)[[1]][2]
     }
     rm(i)
     DF <- dfl
@@ -36,7 +38,7 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
     for (i in 1:nrow(dfl)) {
         if (isTRUE(dfl[i, 1] != dfl[i, 2]) == TRUE) 
             DF[k, ] <- dfl[i, ]
-        k <- k + 1L
+        k <- k + 1
     }
     rm(i)
     rm(k)
@@ -55,8 +57,8 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
     finn <- list()
     fout <- list()
     for (i in seq(lbs)) {
-        finn[[i]] <- which(tabulate(inn[[i]]) == dim(m)[3])
-        fout[[i]] <- which(tabulate(out[[i]]) == dim(m)[3])
+        finn[[i]] <- which(tabulate(inn[[i]]) == dim(x)[3])
+        fout[[i]] <- which(tabulate(out[[i]]) == dim(x)[3])
     }
     rm(i)
     full <- list()
@@ -82,7 +84,7 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         tmprte <- vector()
         for (j in 1:length(dobl[[i]])) {
             if (isTRUE(dobl[[i]][j] %in% which(tabulate(inn[[i]]) == 
-                1L)) == TRUE && isTRUE(dobl[[i]][j] %in% which(tabulate(out[[i]]) == 
+                1)) == TRUE && isTRUE(dobl[[i]][j] %in% which(tabulate(out[[i]]) == 
                 1)) == TRUE) 
                 tmprte[length(tmprte) + 1L] <- dobl[[i]][j]
         }
@@ -91,26 +93,26 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
     }
     rm(i)
     rm(tmprte)
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         tmp <- list()
         tt <- vector()
-        if (isTRUE(is.null(dimnames(m)[[3]])) == FALSE) {
-            for (i in 1:length(dimnames(m)[[3]])) tmp[i] <- dimnames(m)[[3]][i]
+        if (isTRUE(is.null(dimnames(x)[[3]])) == FALSE) {
+            for (i in 1:length(dimnames(x)[[3]])) tmp[i] <- dimnames(x)[[3]][i]
             rm(i)
             for (i in 1:length(tmp)) tt[i] <- (strsplit(tmp[[i]], 
                 "")[[1]][1])
             rm(i)
         }
         else {
-            for (i in 1:dim(m)[3]) tt[i] <- tmp[i] <- i
+            for (i in 1:dim(x)[3]) tt[i] <- tmp[i] <- i
             rm(i)
         }
         for (k in 1:length(tt)) {
             allr <- paste("all", tt[k], sep = "_")
-            assign(allr, transf(dichot(m)[, , k], "matlist", 
+            assign(allr, transf(dichot(x)[, , k], type = "matlist", 
                 labels = lbs, prsep = prsep, lb2lb = lb2lb))
-            tmp <- transf(dichot(m)[, , k], "matlist", labels = lbs, 
-                prsep = prsep, lb2lb = lb2lb)
+            tmp <- transf(dichot(x)[, , k], type = "matlist", 
+                labels = lbs, prsep = prsep, lb2lb = lb2lb)
             tDF <- data.frame(matrix(ncol = 2L, nrow = 0L))
             for (i in 1:length(tmp)) {
                 tDF[i, 1] <- strsplit(tmp[i], prsep)[[1]][1]
@@ -135,12 +137,12 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         }
         rm(k)
     }
-    else if (isTRUE(is.na(dim(m)[3])) == FALSE | isTRUE(dim(m)[3] == 
+    else if (isTRUE(is.na(dim(x)[3])) == FALSE | isTRUE(dim(x)[3] == 
         1L) == TRUE) {
         tt <- "R"
         tmp <- x
     }
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         for (k in 1:length(tt)) {
             tmpxchg <- list()
             xchr <- paste("xch", tt[k], sep = "_")
@@ -149,7 +151,7 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
                 tmpxchr <- vector()
                 for (j in 1:length(rete[[i]])) {
                   ifelse(isTRUE(rete[[i]][j] %in% which(tabulate(eval(as.name(allr))[[i]]) == 
-                    1)) == TRUE, tmpxchr[length(tmpxchr) + 1L] <- rete[[i]][j], 
+                    1L)) == TRUE, tmpxchr[length(tmpxchr) + 1L] <- rete[[i]][j], 
                     NA)
                 }
                 rm(j)
@@ -169,7 +171,7 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
                 vecr <- paste("vec", i, sep = "")
                 tmpxch <- vector()
                 tmpxch <- eval(as.name(xchr))[[i]]
-                if (sum(tmpxch) > 0) {
+                if (sum(tmpxch) > 0L) {
                   assign(vecr, tmpxch)
                   xchg[[i]] <- eval(as.name(vecr))
                   rm(vecr)
@@ -185,10 +187,10 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         rm(xchr)
     }
     else {
-        xchg <- logical(0)
+        xchg <- character(0)
     }
     recp <- list()
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         for (i in 1:length(rete)) {
             recp[[i]] <- rete[[i]][which(!(rete[[i]] %in% xchg[[i]]))]
         }
@@ -197,7 +199,7 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
     else {
         recp <- rete
     }
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         Eout <- list()
         length(Eout) <- length(lbs)
         for (i in 1:length(dobl)) {
@@ -228,9 +230,9 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
             tmpout <- vector()
             for (j in 1:length(trpr[[i]])) {
                 if (isTRUE(trpr[[i]][j] %in% tinn[[i]]) == TRUE) 
-                  tmpinn[length(tmpinn) + 1] <- trpr[[i]][j]
+                  tmpinn[length(tmpinn) + 1L] <- trpr[[i]][j]
                 if (isTRUE(trpr[[i]][j] %in% tout[[i]]) == TRUE) 
-                  tmpout[length(tmpout) + 1] <- trpr[[i]][j]
+                  tmpout[length(tmpout) + 1L] <- trpr[[i]][j]
             }
             rm(j)
             teinn[[i]] <- tmpinn
@@ -258,10 +260,10 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         rm(tmpinn, tmpout)
     }
     else {
-        TEinn <- TEout <- Eout <- logical(0)
+        TEinn <- TEout <- Eout <- character(0)
     }
     mix <- list()
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         for (i in 1:length(trpr)) {
             mix[[i]] <- trpr[[i]][which(!(trpr[[i]] %in% TEinn[[i]] | 
                 trpr[[i]] %in% TEout[[i]]))]
@@ -274,13 +276,13 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         rm(i)
     }
     else {
-        mixe <- logical(0)
+        mixe <- character(0)
     }
     As <- vector()
     for (i in 1:length(asym)) {
         for (j in 1:length(asym[[i]])) {
             if (isTRUE(length(asym[[i]]) != 0L) == TRUE) {
-                if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+                if (isTRUE(is.na(dim(x)[3])) == FALSE) {
                   As <- append(As, paste(lbs[i], asym[[i]][j], 
                     sep = prsep))
                 }
@@ -294,21 +296,21 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         rm(j)
     }
     rm(i)
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         AS <- list()
         for (k in 1:length(tt)) {
             tmp <- vector()
-            for (i in which(As %in% transf(m[, , k], labels = lbs, 
+            for (i in which(As %in% transf(x[, , k], labels = lbs, 
                 prsep = prsep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, As[i])
             }
             rm(i)
-            AS[[k]] <- tmp
+            AS[[k]] <- as.character(tmp)
         }
         rm(k)
     }
     else {
-        AS <- As
+        AS <- as.character(As)
     }
     Rp <- vector()
     for (i in 1:length(recp)) {
@@ -321,24 +323,24 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         rm(j)
     }
     rm(i)
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         RP <- list()
         for (k in 1:length(tt)) {
             tmp <- vector()
-            for (i in which(Rp %in% transf(m[, , k], labels = lbs, 
+            for (i in which(Rp %in% transf(x[, , k], labels = lbs, 
                 prsep = prsep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, Rp[i])
             }
             rm(i)
-            RP[[k]] <- tmp
+            RP[[k]] <- as.character(tmp)
         }
         rm(k)
     }
     else {
-        RP <- Rp
+        RP <- as.character(Rp)
     }
     Xc <- vector()
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         for (i in 1:length(xchg)) {
             for (j in 1:length(xchg[[i]])) {
                 if (isTRUE(length(xchg[[i]]) != 0L) == TRUE) {
@@ -355,12 +357,12 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         for (k in 1:length(tt)) {
             tmp <- vector()
             tmpt <- vector()
-            for (i in which(Xc %in% transf(m[, , k], labels = lbs, 
+            for (i in which(Xc %in% transf(x[, , k], labels = lbs, 
                 prsep = prsep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, Xc[i])
             }
             rm(i)
-            for (i in which(Xc %in% transf(t(m[, , k]), labels = lbs, 
+            for (i in which(Xc %in% transf(t(x[, , k]), labels = lbs, 
                 prsep = prsep, lb2lb = lb2lb))) {
                 tmpt <- append(tmpt, paste(strsplit(Xc[i], prsep)[[1]][2], 
                   strsplit(Xc[i], prsep)[[1]][1], sep = prsep))
@@ -372,15 +374,15 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         rm(k)
         XCH <- list()
         for (i in 1:length(XC)) {
-            XCH[[i]] <- c(XC[[i]], XCt[[i]])
+            XCH[[i]] <- as.character(c(XC[[i]], XCt[[i]]))
         }
         rm(i)
     }
     else {
-        XCH <- Xc
+        XCH <- as.character(Xc)
     }
     Et <- vector()
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         for (i in 1:length(Eout)) {
             for (j in 1:length(Eout[[i]])) {
                 if (isTRUE(length(Eout[[i]]) != 0L) == TRUE) {
@@ -405,20 +407,20 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         ENT <- list()
         for (k in 1:length(tt)) {
             tmp <- vector()
-            for (i in which(Et %in% transf(m[, , k], labels = lbs, 
+            for (i in which(Et %in% transf(x[, , k], labels = lbs, 
                 prsep = prsep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, Et[i])
             }
             rm(i)
-            ENT[[k]] <- tmp
+            ENT[[k]] <- as.character(tmp)
         }
         rm(k)
     }
     else {
-        ENT <- Et
+        ENT <- as.character(Et)
     }
     Mx <- vector()
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         for (i in 1:length(mixe)) {
             for (j in 1:length(mixe[[i]])) {
                 if (isTRUE(length(mixe[[i]]) != 0L) == TRUE) {
@@ -435,12 +437,12 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         for (k in 1:length(tt)) {
             tmp <- vector()
             tmpt <- vector()
-            for (i in which(Mx %in% transf(m[, , k], labels = lbs, 
+            for (i in which(Mx %in% transf(x[, , k], labels = lbs, 
                 prsep = prsep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, Mx[i])
             }
             rm(i)
-            for (i in which(Mx %in% transf(t(m[, , k]), labels = lbs, 
+            for (i in which(Mx %in% transf(t(x[, , k]), labels = lbs, 
                 prsep = prsep, lb2lb = lb2lb))) {
                 tmpt <- append(tmpt, paste(strsplit(Mx[i], prsep)[[1]][2], 
                   strsplit(Mx[i], prsep)[[1]][1], sep = prsep))
@@ -452,15 +454,15 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         rm(k)
         MIX <- list()
         for (i in 1:length(MX)) {
-            MIX[[i]] <- c(MX[[i]], MXt[[i]])
+            MIX[[i]] <- as.character(c(MX[[i]], MXt[[i]]))
         }
         rm(i)
     }
     else {
-        MIX <- Mx
+        MIX <- as.character(Mx)
     }
     Fl <- vector()
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         for (i in 1:length(full)) {
             for (j in 1:length(full[[i]])) {
                 if (isTRUE(length(full[[i]]) != 0L) == TRUE) {
@@ -477,12 +479,12 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         for (k in 1:length(tt)) {
             tmp <- vector()
             tmpt <- vector()
-            for (i in which(Fl %in% transf(m[, , k], labels = lbs, 
+            for (i in which(Fl %in% transf(x[, , k], labels = lbs, 
                 prsep = prsep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, Fl[i])
             }
             rm(i)
-            for (i in which(Fl %in% transf(t(m[, , k]), labels = lbs, 
+            for (i in which(Fl %in% transf(t(x[, , k]), labels = lbs, 
                 prsep = prsep, lb2lb = lb2lb))) {
                 tmpt <- append(tmpt, paste(strsplit(Fl[i], prsep)[[1]][2], 
                   strsplit(Fl[i], prsep)[[1]][1], sep = prsep))
@@ -494,21 +496,21 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         rm(k)
         FUL <- list()
         for (i in 1:length(FL)) {
-            FUL[[i]] <- c(FL[[i]], FLt[[i]])
+            FUL[[i]] <- as.character(c(FL[[i]], FLt[[i]]))
         }
         rm(i)
     }
     else {
-        FUL <- Fl
+        FUL <- as.character(Fl)
     }
     if (lb2lb) {
-        if (isTRUE(is.null(dimnames(m)[[1]]) == TRUE) == FALSE) {
+        if (isTRUE(is.null(dimnames(x)[[1]]) == TRUE) == FALSE) {
             if (length(AS) > 0L) {
                 for (k in 1:length(AS)) {
                   for (i in 1:length(AS[[k]])) {
                     if (length(AS[[k]]) > 0L) {
-                      AS[[k]][i] <- paste(dimnames(m)[[1]][as.numeric(strsplit(AS[[k]][i], 
-                        prsep)[[1]][1])], dimnames(m)[[1]][as.numeric(strsplit(AS[[k]][i], 
+                      AS[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(AS[[k]][i], 
+                        prsep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(AS[[k]][i], 
                         prsep)[[1]][2])], sep = prsep)
                     }
                   }
@@ -520,8 +522,8 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
                 for (k in 1:length(RP)) {
                   for (i in 1:length(RP[[k]])) {
                     if (length(RP[[k]]) > 0L) {
-                      RP[[k]][i] <- paste(dimnames(m)[[1]][as.numeric(strsplit(RP[[k]][i], 
-                        prsep)[[1]][1])], dimnames(m)[[1]][as.numeric(strsplit(RP[[k]][i], 
+                      RP[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(RP[[k]][i], 
+                        prsep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(RP[[k]][i], 
                         prsep)[[1]][2])], sep = prsep)
                     }
                   }
@@ -529,13 +531,13 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
                 }
                 rm(k)
             }
-            if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+            if (isTRUE(is.na(dim(x)[3])) == FALSE) {
                 if (length(XCH) > 0L) {
                   for (k in 1:length(XCH)) {
                     for (i in 1:length(XCH[[k]])) {
                       if (length(XCH[[k]]) > 0L) {
-                        XCH[[k]][i] <- paste(dimnames(m)[[1]][as.numeric(strsplit(XCH[[k]][i], 
-                          prsep)[[1]][1])], dimnames(m)[[1]][as.numeric(strsplit(XCH[[k]][i], 
+                        XCH[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(XCH[[k]][i], 
+                          prsep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(XCH[[k]][i], 
                           prsep)[[1]][2])], sep = prsep)
                       }
                     }
@@ -547,8 +549,8 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
                   for (k in 1:length(ENT)) {
                     for (i in 1:length(ENT[[k]])) {
                       if (length(ENT[[k]]) > 0L) {
-                        ENT[[k]][i] <- paste(dimnames(m)[[1]][as.numeric(strsplit(ENT[[k]][i], 
-                          prsep)[[1]][1])], dimnames(m)[[1]][as.numeric(strsplit(ENT[[k]][i], 
+                        ENT[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(ENT[[k]][i], 
+                          prsep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(ENT[[k]][i], 
                           prsep)[[1]][2])], sep = prsep)
                       }
                     }
@@ -560,8 +562,8 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
                   for (k in 1:length(MIX)) {
                     for (i in 1:length(MIX[[k]])) {
                       if (length(MIX[[k]]) > 0L) {
-                        MIX[[k]][i] <- paste(dimnames(m)[[1]][as.numeric(strsplit(MIX[[k]][i], 
-                          prsep)[[1]][1])], dimnames(m)[[1]][as.numeric(strsplit(MIX[[k]][i], 
+                        MIX[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(MIX[[k]][i], 
+                          prsep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(MIX[[k]][i], 
                           prsep)[[1]][2])], sep = prsep)
                       }
                     }
@@ -573,8 +575,8 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
                   for (k in 1:length(FUL)) {
                     for (i in 1:length(FUL[[k]])) {
                       if (length(FUL[[k]]) > 0L) {
-                        FUL[[k]][i] <- paste(dimnames(m)[[1]][as.numeric(strsplit(FUL[[k]][i], 
-                          prsep)[[1]][1])], dimnames(m)[[1]][as.numeric(strsplit(FUL[[k]][i], 
+                        FUL[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(FUL[[k]][i], 
+                          prsep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(FUL[[k]][i], 
                           prsep)[[1]][2])], sep = prsep)
                       }
                     }
@@ -586,20 +588,20 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
         }
     }
     if (loops) {
-        if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+        if (isTRUE(is.na(dim(x)[3])) == FALSE) {
             LOP <- list()
-            length(LOP) <- dim(m)[3]
-            for (i in 1:dim(m)[3]) {
-                lp <- which(diag(m[, , i]) != 0L)
+            length(LOP) <- dim(x)[3]
+            for (i in 1:dim(x)[3]) {
+                lp <- which(diag(x[, , i]) != 0L)
                 if (isTRUE(length(lp) > 0L) == TRUE) {
                   for (j in 1:length(lp)) {
                     if (lb2lb) {
-                      if (isTRUE(is.null(dimnames(m)[[1]])) == 
+                      if (isTRUE(is.null(dimnames(x)[[1]])) == 
                         FALSE) {
-                        LOP[[i]] <- append(LOP[[i]], paste(dimnames(m)[[1]][lp][j], 
-                          dimnames(m)[[1]][lp][j], sep = prsep))
+                        LOP[[i]] <- append(LOP[[i]], paste(dimnames(x)[[1]][lp][j], 
+                          dimnames(x)[[1]][lp][j], sep = prsep))
                       }
-                      else if (isTRUE(is.null(dimnames(m)[[1]])) == 
+                      else if (isTRUE(is.null(dimnames(x)[[1]])) == 
                         TRUE) {
                         LOP[[i]] <- append(LOP[[i]], paste(lp[j], 
                           lp[j], sep = prsep))
@@ -613,28 +615,28 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
                   rm(j)
                 }
                 else {
-                  LOP[[i]] <- logical(0)
+                  LOP[[i]] <- character(0)
                 }
             }
             rm(i)
-            attr(LOP, "names") <- dimnames(m)[[3]]
+            attr(LOP, "names") <- dimnames(x)[[3]]
         }
         else {
             LOP <- vector()
-            lp <- which(diag(m) != 0L)
+            lp <- which(diag(x) != 0L)
             for (j in 1:length(lp)) {
-                LOP <- append(LOP, paste(dimnames(m)[[1]][lp][j], 
-                  dimnames(m)[[1]][lp][j], sep = prsep))
+                LOP <- append(LOP, paste(dimnames(x)[[1]][lp][j], 
+                  dimnames(x)[[1]][lp][j], sep = prsep))
             }
             rm(j)
         }
-        ifelse(isTRUE(smpl == FALSE) == TRUE, attr(LOP, "names") <- dimnames(m)[[3]], 
+        ifelse(isTRUE(smpl == FALSE) == TRUE, attr(LOP, "names") <- dimnames(x)[[3]], 
             attr(LOP, "names") <- tt)
     }
-    if (isTRUE(is.na(dim(m)[3])) == FALSE) {
+    if (isTRUE(is.na(dim(x)[3])) == FALSE) {
         ifelse(isTRUE(smpl == FALSE) == TRUE, attr(FUL, "names") <- attr(MIX, 
             "names") <- attr(ENT, "names") <- attr(XCH, "names") <- attr(RP, 
-            "names") <- attr(AS, "names") <- dimnames(m)[[3]], 
+            "names") <- attr(AS, "names") <- dimnames(x)[[3]], 
             attr(FUL, "names") <- attr(MIX, "names") <- attr(ENT, 
                 "names") <- attr(XCH, "names") <- attr(RP, "names") <- attr(AS, 
                 "names") <- tt)
@@ -642,17 +644,17 @@ function (m, loops = FALSE, prsep = ", ", smpl = FALSE, lb2lb = TRUE,
     if (collapse) {
         ifelse(isTRUE(loops == FALSE) == TRUE, lst <- list(asym = as.vector(unlist(AS)), 
             recp = as.vector(unlist(RP)), tent = as.vector(unlist(ENT)), 
-            txch = as.vector(unlist(XCH)), mixed = as.vector(unlist(MIX)), 
+            txch = as.vector(unlist(XCH)), mixd = as.vector(unlist(MIX)), 
             full = as.vector(unlist(FUL))), lst <- list(asym = as.vector(unlist(AS)), 
             recp = as.vector(unlist(RP)), tent = as.vector(unlist(ENT)), 
-            txch = as.vector(unlist(XCH)), mixed = as.vector(unlist(MIX)), 
+            txch = as.vector(unlist(XCH)), mixd = as.vector(unlist(MIX)), 
             full = as.vector(unlist(FUL)), loop = as.vector(unlist(LOP))))
     }
     else {
         ifelse(isTRUE(loops == FALSE) == TRUE, lst <- list(asym = AS, 
-            recp = RP, tent = ENT, txch = XCH, mixed = MIX, full = FUL), 
+            recp = RP, tent = ENT, txch = XCH, mixd = MIX, full = FUL), 
             lst <- list(asym = AS, recp = RP, tent = ENT, txch = XCH, 
-                mixed = MIX, full = FUL, loop = LOP))
+                mixd = MIX, full = FUL, loop = LOP))
     }
     class(lst) <- "Rel.Bundles"
     return(lst)
