@@ -1,17 +1,18 @@
 semigroup <-
-function(x, type = c("numerical","symbolic"), labels = NULL, cmp = FALSE, smpl = FALSE)
+function (x, type = c("numerical", "symbolic"), labels = NULL, 
+    cmp = FALSE, smpl = FALSE) 
 {
-if (is.array(x) == FALSE) 
-    stop("Data must be a stacked array of square matrices.")
-#
-X <- x # <=- input data, por su acaso
-if (is.na(dim(x)[3]) == FALSE) {
-	if(is.null(labels) == FALSE) dimnames(x)[[3]] <- labels 
-	if(is.null(dimnames(x)[[3]]) == TRUE) dimnames(X)[[3]] <- 1:dim(x)[3]
-}
-x <- replace(x, x < 1, 0)
-x <- replace(x, x >= 1, 1)
-### SIMPLIFY labels ###
+    if (is.array(x) == FALSE) 
+        stop("Data must be a stacked array of square matrices.")
+    X <- x
+    if (is.na(dim(x)[3]) == FALSE) {
+        if (is.null(labels) == FALSE) 
+            dimnames(x)[[3]] <- labels
+        if (is.null(dimnames(x)[[3]]) == TRUE) 
+            dimnames(X)[[3]] <- 1:dim(x)[3]
+    }
+    x <- replace(x, x < 1, 0)
+    x <- replace(x, x >= 1, 1)
     if (smpl == TRUE) {
         ifelse(is.null(dimnames(x)[[3]]) == FALSE, lbs <- dimnames(x)[[3]], 
             lbs <- 1:dim(x)[3])
@@ -27,43 +28,51 @@ x <- replace(x, x >= 1, 1)
             dimnames(x)[[3]] <- lbs
         }
     }
-### ONE MATRIX ###
     if (is.na(dim(x)[3]) == TRUE) {
         s0 <- data.frame(matrix(ncol = 1, nrow = 1))
-        if (isTRUE(all.equal(replace(x %*% x, x %*% x >= 
-            1, 1), x) == TRUE)) 
+        if (isTRUE(all.equal(replace(x %*% x, x %*% x >= 1, 1), 
+            x) == TRUE)) 
             s0[1, 1] <- 1
         Bx <- array(dim = c(dim(x)[1], dim(x)[2], 2))
         Bx[, , 1] <- as.matrix(x)
         Bx[, , 2] <- replace(x %*% x, x %*% x >= 1, 1)
     }
-###  2+ MATRICES  ###
     if (is.na(dim(x)[3]) == FALSE) {
-        tmpo<-data.frame(matrix(ncol=(dim(x)[1]*dim(x)[2]),nrow=0))
+        tmpo <- data.frame(matrix(ncol = (dim(x)[1] * dim(x)[2]), 
+            nrow = 0))
         for (i in 1:dim(x)[3]) {
-        	ifelse(isTRUE(dim(x)[3]>1)==TRUE, tmpo[i,]<-as.vector(x[,,i]), tmpo<-as.vector(x))
-        }; rm(i)
-        if(isTRUE(is.character(dimnames(x)[[3]])==TRUE)==TRUE) dimnames(x)[[3]][which(duplicated(dimnames(x)[[3]]))] <- 1:length(which(duplicated(dimnames(x)[[3]])))
-        if(isTRUE(is.null(dim(tmpo))==FALSE)==TRUE) rownames(tmpo)<-dimnames(x)[[3]]
-        tmpu<-unique(tmpo)
-#
-        if(isTRUE(dim(x)[3]<2)==TRUE) x<-array(tmpo,c(dim(x)[1],dim(x)[2])) 
-        if(isTRUE(dim(x)[3]>1)==TRUE) {
-        tmp<-array(dim=c(dim(x)[1],dim(x)[2],nrow(tmpu)))
-        for (i in 1:nrow(tmpu)) {
-        	tmp[,,i][1:(dim(x)[1]*dim(x)[2])]<-as.numeric(tmpu[i,])
-        }; rm(i)
-        if(is.null(dimnames(tmp)[[1]])==FALSE) dimnames(tmp)[[3]]<-rownames(tmpu)
-        if(is.null(dimnames(x)[[1]])==FALSE) dimnames(tmp)[[1]]<-dimnames(tmp)[[2]]<-dimnames(x)[[1]]
-        x<-tmp
-        dimnames(x)[[3]]<-as.list(rownames(tmpu))
+            ifelse(isTRUE(dim(x)[3] > 1) == TRUE, tmpo[i, ] <- as.vector(x[, 
+                , i]), tmpo <- as.vector(x))
+        }
+        rm(i)
+        if (isTRUE(is.character(dimnames(x)[[3]]) == TRUE) == 
+            TRUE) 
+            dimnames(x)[[3]][which(duplicated(dimnames(x)[[3]]))] <- 1:length(which(duplicated(dimnames(x)[[3]])))
+        if (isTRUE(is.null(dim(tmpo)) == FALSE) == TRUE) 
+            rownames(tmpo) <- dimnames(x)[[3]]
+        tmpu <- unique(tmpo)
+        if (isTRUE(dim(x)[3] < 2) == TRUE) 
+            x <- array(tmpo, c(dim(x)[1], dim(x)[2]))
+        if (isTRUE(dim(x)[3] > 1) == TRUE) {
+            tmp <- array(dim = c(dim(x)[1], dim(x)[2], nrow(tmpu)))
+            for (i in 1:nrow(tmpu)) {
+                tmp[, , i][1:(dim(x)[1] * dim(x)[2])] <- as.numeric(tmpu[i, 
+                  ])
+            }
+            rm(i)
+            if (is.null(dimnames(tmp)[[1]]) == FALSE) 
+                dimnames(tmp)[[3]] <- rownames(tmpu)
+            if (is.null(dimnames(x)[[1]]) == FALSE) 
+                dimnames(tmp)[[1]] <- dimnames(tmp)[[2]] <- dimnames(x)[[1]]
+            x <- tmp
+            dimnames(x)[[3]] <- as.list(rownames(tmpu))
         }
         rm(tmp)
-        # s0 ##
         s0 <- data.frame(matrix(ncol = dim(x)[3], nrow = dim(x)[3]))
         for (k in 1:dim(x)[3]) {
             for (j in 1:dim(x)[3]) {
-                tmp<-x[, , j] %*% x[, , k]; tmp<-replace(tmp,tmp>=1,1)
+                tmp <- x[, , j] %*% x[, , k]
+                tmp <- replace(tmp, tmp >= 1, 1)
                 for (i in dim(x)[3]:1) {
                   if (isTRUE(all.equal(tmp, x[, , i]) == TRUE)) 
                     s0[j, k] <- i
@@ -82,19 +91,20 @@ x <- replace(x, x >= 1, 1)
                   if (length(which(is.na(s0[i, ]))) > 0) 
                     Bx <- zbnd(Bx, (replace(x[, , i] %*% x[, 
                       , which(is.na(s0[i, ]))[j]], x[, , i] %*% 
-                      x[, , which(is.na(s0[i, ]))[j]] >= 1, 
-                      1)))
+                      x[, , which(is.na(s0[i, ]))[j]] >= 1, 1)))
                 }
             }
             rm(i, j)
-            tmp <- data.frame(matrix(ncol = (dim(x)[1] * dim(x)[2]), nrow = 0))
+            tmp <- data.frame(matrix(ncol = (dim(x)[1] * dim(x)[2]), 
+                nrow = 0))
             for (i in 1:dim(Bx)[3]) {
                 tmp[i, ] <- as.vector(Bx[, , i])
             }
             rm(i)
             xBx <- array(dim = c(dim(x)[1], dim(x)[2], nrow(unique(tmp))))
             for (i in 1:nrow(unique(tmp))) {
-                xBx[, , i][1:(dim(Bx)[1] * dim(Bx)[2])] <- as.numeric(unique(tmp)[i,])
+                xBx[, , i][1:(dim(Bx)[1] * dim(Bx)[2])] <- as.numeric(unique(tmp)[i, 
+                  ])
             }
             rm(i)
             if (is.null(dimnames(xBx)) == FALSE) 
@@ -104,7 +114,6 @@ x <- replace(x, x >= 1, 1)
             rm(xBx, tmp)
         }
     }
-##  EDGE TABLE CONSTRUCTION  ##
     while (sum(as.numeric(is.na(s0))) > 0) {
         BBx <- Bx
         for (i in 1:nrow(s0)) {
@@ -116,22 +125,24 @@ x <- replace(x, x >= 1, 1)
             }
         }
         rm(i, j)
-        tmp <- data.frame(matrix(ncol = (dim(Bx)[1] * dim(Bx)[2]), nrow = 0))
+        tmp <- data.frame(matrix(ncol = (dim(Bx)[1] * dim(Bx)[2]), 
+            nrow = 0))
         for (i in 1:dim(BBx)[3]) {
             tmp[i, ] <- as.vector(BBx[, , i])
         }
         rm(i)
         Bx <- array(dim = c(dim(x)[1], dim(x)[2], nrow(unique(tmp))))
         for (i in 1:nrow(unique(tmp))) {
-            Bx[, , i][1:(dim(BBx)[1] * dim(BBx)[2])] <- as.numeric(unique(tmp)[i,])
+            Bx[, , i][1:(dim(BBx)[1] * dim(BBx)[2])] <- as.numeric(unique(tmp)[i, 
+                ])
         }
         rm(i)
         rm(tmp, BBx)
-	### edgeT const CASE: 1
         if (is.na(dim(x)[3]) == TRUE) {
             s0 <- data.frame(matrix(ncol = 1, nrow = dim(Bx)[3]))
             for (j in 1:dim(Bx)[3]) {
-                tmp<-Bx[,,j]%*%Bx[,,1]; tmp<-replace(tmp,tmp>=1,1)
+                tmp <- Bx[, , j] %*% Bx[, , 1]
+                tmp <- replace(tmp, tmp >= 1, 1)
                 for (i in dim(Bx)[3]:1) {
                   if (isTRUE(all.equal(tmp, Bx[, , i]) == TRUE)) 
                     s0[j, 1] <- i
@@ -139,12 +150,12 @@ x <- replace(x, x >= 1, 1)
             }
             rm(i, j)
         }
-	### edgeT const CASE: 2+
         if (is.na(dim(x)[3]) == FALSE) {
             s0 <- data.frame(matrix(ncol = dim(x)[3], nrow = dim(Bx)[3]))
             for (k in 1:dim(x)[3]) {
                 for (j in 1:dim(Bx)[3]) {
-                tmp<-Bx[,,j]%*%Bx[,,k]; tmp<-replace(tmp,tmp>=1,1)
+                  tmp <- Bx[, , j] %*% Bx[, , k]
+                  tmp <- replace(tmp, tmp >= 1, 1)
                   for (i in dim(Bx)[3]:1) {
                     if (isTRUE(all.equal(tmp, Bx[, , i]) == TRUE)) 
                       s0[j, k] <- i
@@ -156,23 +167,24 @@ x <- replace(x, x >= 1, 1)
     }
     ifelse(isTRUE(is.na(dim(x)[3])) == TRUE, dimnames(s0)[[2]] <- 1, 
         dimnames(s0)[[2]] <- 1:dim(x)[3])
-## FINALES when Bx has duplicates, e.g. U-matrix?
-	tmpO<-data.frame(matrix(ncol=(dim(Bx)[1]*dim(Bx)[2]),nrow=0))
-	for (i in 1:dim(Bx)[3]) {
-		tmpO[i,]<-as.vector(Bx[,,i])
-	}; rm(i)
-	rownames(tmpO)<-dimnames(Bx)[[3]]
-	tmpU<-unique(tmpO)
-	tmp<-array(dim=c(dim(Bx)[1],dim(Bx)[2],nrow(tmpU)))
-	for (i in 1:nrow(tmpU)) {
-		tmp[,,i][1:(dim(Bx)[1]*dim(Bx)[2])]<-as.numeric(tmpU[i,])
-	}; rm(i)
-	Bx<-tmp
-	dimnames(Bx)[[3]]<-as.list(rownames(tmpU))
-####     EDGE TABLE   ###
+    tmpO <- data.frame(matrix(ncol = (dim(Bx)[1] * dim(Bx)[2]), 
+        nrow = 0))
+    for (i in 1:dim(Bx)[3]) {
+        tmpO[i, ] <- as.vector(Bx[, , i])
+    }
+    rm(i)
+    rownames(tmpO) <- dimnames(Bx)[[3]]
+    tmpU <- unique(tmpO)
+    tmp <- array(dim = c(dim(Bx)[1], dim(Bx)[2], nrow(tmpU)))
+    for (i in 1:nrow(tmpU)) {
+        tmp[, , i][1:(dim(Bx)[1] * dim(Bx)[2])] <- as.numeric(tmpU[i, 
+            ])
+    }
+    rm(i)
+    Bx <- tmp
+    dimnames(Bx)[[3]] <- as.list(rownames(tmpU))
     E <- s0
     rm(s0)
-#### WORD TABLE W(n,g) ####
     if (dim(Bx)[3] == ncol(E)) {
         W <- rbind(cbind(1:ncol(E), NA, NA))
         colnames(W) <- c("", "n", "g")
@@ -200,7 +212,6 @@ x <- replace(x, x >= 1, 1)
         rm(z, n, g)
     }
     rm(tmp)
-####  L A B E L S  ###
     if (is.na(dim(x)[3]) == TRUE) {
         ifelse(is.null(dimnames(Bx)[[3]]) == TRUE, lbl <- 1:dim(Bx)[3], 
             lbl <- dimnames(Bx)[[3]])
@@ -285,128 +296,131 @@ x <- replace(x, x >= 1, 1)
                 sep = "")
         }
         rm(i)
-############
-## LENGTH 8 ##
-for (i in 
-which(W[,2]<
-  (which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>
-     ncol(E))[1]))[1]))[1]))[1])
-   ))[1])[1])
-)[
-(length(which(W[,2]<(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>
-   ncol(E))[1]))[1]))[1])))[1])[1])))+1):
- length(which(W[,2]<(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>
-    ncol(E))[1]))[1]))[1]))[1])))[1])[1])))
- ]
- ) {
-lbl[(i)]<-paste(dimnames(Bx)[[3]][W[W[W[W[W[W[W[W[,2][i],],][1,][2],][2],][2],][2],][2],][2]],
-		dimnames(Bx)[[3]][W[W[W[W[W[W[W[W[,2][i],],][1,][2],][2],][2],][2],][2],][3]],
-		dimnames(Bx)[[3]][W[W[W[W[W[W[W[,2][i],],][1,][2],][2],][2],][2],][3]],
-		dimnames(Bx)[[3]][W[W[W[W[W[W[,2][i],],][1,][2],][2],][2],][3]],
-		dimnames(Bx)[[3]][W[W[W[W[W[,2][i],],][1,][2],][2],][3]],
-		dimnames(Bx)[[3]][W[W[W[W[,2][i],],][1,][2],][3]],
-		dimnames(Bx)[[3]][W[W[,2][i],][3]],
-		dimnames(Bx)[[3]][W[,3][i]],
-		sep="")
- }
- rm(i)
-############
-## LENGTH 9
-for (i in 
-which(W[,2]<
-  (which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>
-     ncol(E))[1]))[1]))[1]))[1]))[1])
-   ))[1])[1])
-)[
-(length(which(W[,2]<(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>
-   ncol(E))[1]))[1]))[1]))[1])))[1])[1])))+1):
- length(which(W[,2]<(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>=(which(W[,2]>
-    ncol(E))[1]))[1]))[1]))[1]))[1])))[1])[1])))
- ]
-) {
-lbl[(i)]<-paste(dimnames(Bx)[[3]][W[W[W[W[W[W[W[W[W[,2][i],],][1,][2],][2],][2],][2],][2],][2],][2]],
-		dimnames(Bx)[[3]][W[W[W[W[W[W[W[W[W[,2][i],],][1,][2],][2],][2],][2],][2],][2],][3]],
-		dimnames(Bx)[[3]][W[W[W[W[W[W[W[W[,2][i],],][1,][2],][2],][2],][2],][2],][3]],
-		dimnames(Bx)[[3]][W[W[W[W[W[W[W[,2][i],],][1,][2],][2],][2],][2],][3]],
-		dimnames(Bx)[[3]][W[W[W[W[W[W[,2][i],],][1,][2],][2],][2],][3]],
-		dimnames(Bx)[[3]][W[W[W[W[W[,2][i],],][1,][2],][2],][3]],
-		dimnames(Bx)[[3]][W[W[W[W[,2][i],],][1,][2],][3]],
-		dimnames(Bx)[[3]][W[W[,2][i],][3]],
-		dimnames(Bx)[[3]][W[,3][i]],
-		sep="")
- }
-rm(i)
-#####
-dimnames(Bx)[[3]] <- lbl
-}
-############
-if (is.null(dimnames(x)[[1]]) == FALSE) 
-     dimnames(Bx)[[1]] <- dimnames(Bx)[[2]] <- dimnames(x)[[1]]
-
-#####   SEMIGROUP  CONSTRUCTION   ###
-switch(match.arg(type),
-  numerical= S <- cbind(E,data.frame(matrix(ncol=(nrow(E)-ncol(E)),nrow=nrow(E)))),
-  symbolic = {
-	e <- E
-	for(i in 1:nrow(E)) {
-	  for(j in 1:ncol(E)) {
-	    e[i,j]<-lbl[as.matrix(E[i,j])]
-	  }; rm(j)
-	}; rm(i)
-   S <- cbind(as.data.frame(e),data.frame(matrix(ncol=(nrow(E)-ncol(E)),nrow=nrow(E))))
-   rm(e) }
-)
-#
-if(ncol(S)!=ncol(E)) {
-for (j in (ncol(E)+1):nrow(E)) {
-  for (i in 1:nrow(E)) {
-	tmp<- replace(Bx[,,i]%*%(Bx[,,as.numeric(which(E==j,arr.ind=TRUE)[1,][1])]%*%Bx[,,as.numeric(which(E==j,arr.ind=TRUE)[1,][2])]),
-	Bx[,,i]%*%(Bx[,,as.numeric(which(E==j,arr.ind=TRUE)[1,][1])]%*%Bx[,,as.numeric(which(E==j,arr.ind=TRUE)[1,][2])])>=1,1)
-	for (k in 1:dim(Bx)[3]) {
-		if(isTRUE(all.equal(Bx[,,k],tmp))==TRUE) {
-		switch(match.arg(type),
-		numerical= S[i,j] <- k,
-		symbolic = S[i,j] <- lbl[k]
-		)
-		break
-		}
-	}; rm(k)
-  }; rm(j)
-}; rm(i)
-rm(tmp)
-} else if(ncol(S)==ncol(E)) {
-for (j in 1:ncol(E)) {
-  for (i in 1:nrow(E)) {
-   for (k in 1:dim(Bx)[3]) {
-		switch(match.arg(type),
-		numerical= NA,
-		symbolic = S[i,j] <- lbl[k] )
-   }
-  }
-}
-}
-#S
-## dimnames, etc.
-    switch( match.arg(type), numerical = dimnames(S)[[1]] <- dimnames(S)[[2]] <- 1:dim(Bx)[3], 
-        symbolic = dimnames(S)[[1]] <- dimnames(S)[[2]] <- lbl )
-    switch( match.arg(type), numerical = S <- as.matrix(S), symbolic = NA )
+        for (i in which(W[, 2] < (which(W[, 2] >= (which(W[, 
+            2] >= (which(W[, 2] >= (which(W[, 2] >= (which(W[, 
+            2] >= (which(W[, 2] > ncol(E))[1]))[1]))[1]))[1])))[1])[1]))[(length(which(W[, 
+            2] < (which(W[, 2] >= (which(W[, 2] >= (which(W[, 
+            2] >= (which(W[, 2] >= (which(W[, 2] > ncol(E))[1]))[1]))[1])))[1])[1]))) + 
+            1):length(which(W[, 2] < (which(W[, 2] >= (which(W[, 
+            2] >= (which(W[, 2] >= (which(W[, 2] >= (which(W[, 
+            2] >= (which(W[, 2] > ncol(E))[1]))[1]))[1]))[1])))[1])[1])))]) {
+            lbl[(i)] <- paste(dimnames(Bx)[[3]][W[W[W[W[W[W[W[W[, 
+                2][i], ], ][1, ][2], ][2], ][2], ][2], ][2], 
+                ][2]], dimnames(Bx)[[3]][W[W[W[W[W[W[W[W[, 2][i], 
+                ], ][1, ][2], ][2], ][2], ][2], ][2], ][3]], 
+                dimnames(Bx)[[3]][W[W[W[W[W[W[W[, 2][i], ], ][1, 
+                  ][2], ][2], ][2], ][2], ][3]], dimnames(Bx)[[3]][W[W[W[W[W[W[, 
+                  2][i], ], ][1, ][2], ][2], ][2], ][3]], dimnames(Bx)[[3]][W[W[W[W[W[, 
+                  2][i], ], ][1, ][2], ][2], ][3]], dimnames(Bx)[[3]][W[W[W[W[, 
+                  2][i], ], ][1, ][2], ][3]], dimnames(Bx)[[3]][W[W[, 
+                  2][i], ][3]], dimnames(Bx)[[3]][W[, 3][i]], 
+                sep = "")
+        }
+        rm(i)
+        for (i in which(W[, 2] < (which(W[, 2] >= (which(W[, 
+            2] >= (which(W[, 2] >= (which(W[, 2] >= (which(W[, 
+            2] >= (which(W[, 2] >= (which(W[, 2] > ncol(E))[1]))[1]))[1]))[1]))[1])))[1])[1]))[(length(which(W[, 
+            2] < (which(W[, 2] >= (which(W[, 2] >= (which(W[, 
+            2] >= (which(W[, 2] >= (which(W[, 2] >= (which(W[, 
+            2] > ncol(E))[1]))[1]))[1]))[1])))[1])[1]))) + 1):length(which(W[, 
+            2] < (which(W[, 2] >= (which(W[, 2] >= (which(W[, 
+            2] >= (which(W[, 2] >= (which(W[, 2] >= (which(W[, 
+            2] >= (which(W[, 2] > ncol(E))[1]))[1]))[1]))[1]))[1])))[1])[1])))]) {
+            lbl[(i)] <- paste(dimnames(Bx)[[3]][W[W[W[W[W[W[W[W[W[, 
+                2][i], ], ][1, ][2], ][2], ][2], ][2], ][2], 
+                ][2], ][2]], dimnames(Bx)[[3]][W[W[W[W[W[W[W[W[W[, 
+                2][i], ], ][1, ][2], ][2], ][2], ][2], ][2], 
+                ][2], ][3]], dimnames(Bx)[[3]][W[W[W[W[W[W[W[W[, 
+                2][i], ], ][1, ][2], ][2], ][2], ][2], ][2], 
+                ][3]], dimnames(Bx)[[3]][W[W[W[W[W[W[W[, 2][i], 
+                ], ][1, ][2], ][2], ][2], ][2], ][3]], dimnames(Bx)[[3]][W[W[W[W[W[W[, 
+                2][i], ], ][1, ][2], ][2], ][2], ][3]], dimnames(Bx)[[3]][W[W[W[W[W[, 
+                2][i], ], ][1, ][2], ][2], ][3]], dimnames(Bx)[[3]][W[W[W[W[, 
+                2][i], ], ][1, ][2], ][3]], dimnames(Bx)[[3]][W[W[, 
+                2][i], ][3]], dimnames(Bx)[[3]][W[, 3][i]], sep = "")
+        }
+        rm(i)
+        dimnames(Bx)[[3]] <- lbl
+    }
+    if (is.null(dimnames(x)[[1]]) == FALSE) 
+        dimnames(Bx)[[1]] <- dimnames(Bx)[[2]] <- dimnames(x)[[1]]
+    switch(match.arg(type), numerical = S <- cbind(E, data.frame(matrix(ncol = (nrow(E) - 
+        ncol(E)), nrow = nrow(E)))), symbolic = {
+        e <- E
+        for (i in 1:nrow(E)) {
+            for (j in 1:ncol(E)) {
+                e[i, j] <- lbl[as.matrix(E[i, j])]
+            }
+            rm(j)
+        }
+        rm(i)
+        S <- cbind(as.data.frame(e), data.frame(matrix(ncol = (nrow(E) - 
+            ncol(E)), nrow = nrow(E))))
+        rm(e)
+    })
+    if (ncol(S) != ncol(E)) {
+        for (j in (ncol(E) + 1):nrow(E)) {
+            for (i in 1:nrow(E)) {
+                tmp <- replace(Bx[, , i] %*% (Bx[, , as.numeric(which(E == 
+                  j, arr.ind = TRUE)[1, ][1])] %*% Bx[, , as.numeric(which(E == 
+                  j, arr.ind = TRUE)[1, ][2])]), Bx[, , i] %*% 
+                  (Bx[, , as.numeric(which(E == j, arr.ind = TRUE)[1, 
+                    ][1])] %*% Bx[, , as.numeric(which(E == j, 
+                    arr.ind = TRUE)[1, ][2])]) >= 1, 1)
+                for (k in 1:dim(Bx)[3]) {
+                  if (isTRUE(all.equal(Bx[, , k], tmp)) == TRUE) {
+                    switch(match.arg(type), numerical = S[i, 
+                      j] <- k, symbolic = S[i, j] <- lbl[k])
+                    break
+                  }
+                }
+                rm(k)
+            }
+            rm(j)
+        }
+        rm(i)
+        rm(tmp)
+    }
+    else if (ncol(S) == ncol(E)) {
+        for (j in 1:ncol(E)) {
+            for (i in 1:nrow(E)) {
+                for (k in 1:dim(Bx)[3]) {
+                  switch(match.arg(type), numerical = NA, symbolic = S[i, 
+                    j] <- lbl[k])
+                }
+            }
+        }
+    }
+    switch(match.arg(type), numerical = dimnames(S)[[1]] <- dimnames(S)[[2]] <- 1:dim(Bx)[3], 
+        symbolic = dimnames(S)[[1]] <- dimnames(S)[[2]] <- lbl)
+    switch(match.arg(type), numerical = S <- as.matrix(S), symbolic = NA)
     if (isTRUE(dim(x)[3] < dim(Bx)[3]) == TRUE) 
         Bx <- Bx[, , (dim(x)[3] + 1):dim(Bx)[3]]
-#
-# Return
-if(is.na(dim(x)[3]) == FALSE) {
-if(isTRUE(nrow(tmpo)==nrow(tmpu))==TRUE) {
-	ifelse(cmp==TRUE, lst <- list(dim=dim(x)[1], gens=x, cmps=Bx, ord=nrow(S), st=lbl, S=S) ,
-	lst <- list(dim=dim(x)[1], gens=x, ord=nrow(S), st=lbl, S=S) )
-} 
-  else {
-	ifelse(cmp==TRUE, lst <- list(dim=dim(x)[1], gens=x, cmps=Bx, ord=nrow(S), Note=paste("Relation ",dimnames(X)[[3]][which(duplicated(tmpo)==TRUE)]," is repeated in the input data and has been equated",sep="\'"), st=lbl, S=S), 
-	lst <- list(dim=dim(x)[1], gens=x, ord=nrow(S), Note=paste("Relation ",dimnames(X)[[3]][which(duplicated(tmpo)==TRUE)]," is repeated in the input data and has been equated",sep="\'"), st=lbl, S=S) )
-}
-} else if(is.na(dim(x)[3]) == TRUE) {
-	ifelse(cmp==TRUE, lst<-list(dim=dim(x)[1], gens=x, cmps=Bx[,,2:dim(Bx)[3]], ord=nrow(S), st=lbl, S=S),lst<-list(dim=dim(x)[1], gens=x, ord=nrow(S), st=lbl, S=S))
-}
+    if (is.na(dim(x)[3]) == FALSE) {
+        if (isTRUE(nrow(tmpo) == nrow(tmpu)) == TRUE) {
+            ifelse(cmp == TRUE, lst <- list(dim = dim(x)[1], 
+                gens = x, cmps = Bx, ord = nrow(S), st = lbl, 
+                S = S), lst <- list(dim = dim(x)[1], gens = x, 
+                ord = nrow(S), st = lbl, S = S))
+        }
+        else {
+            ifelse(cmp == TRUE, lst <- list(dim = dim(x)[1], 
+                gens = x, cmps = Bx, ord = nrow(S), Note = paste("Relation ", 
+                  dimnames(X)[[3]][which(duplicated(tmpo) == 
+                    TRUE)], " is repeated in the input data and has been equated", 
+                  sep = "'"), st = lbl, S = S), lst <- list(dim = dim(x)[1], 
+                gens = x, ord = nrow(S), Note = paste("Relation ", 
+                  dimnames(X)[[3]][which(duplicated(tmpo) == 
+                    TRUE)], " is repeated in the input data and has been equated", 
+                  sep = "'"), st = lbl, S = S))
+        }
+    }
+    else if (is.na(dim(x)[3]) == TRUE) {
+        ifelse(cmp == TRUE, lst <- list(dim = dim(x)[1], gens = x, 
+            cmps = Bx[, , 2:dim(Bx)[3]], ord = nrow(S), st = lbl, 
+            S = S), lst <- list(dim = dim(x)[1], gens = x, ord = nrow(S), 
+            st = lbl, S = S))
+    }
     class(lst) <- c("Semigroup", match.arg(type))
     return(lst)
-
 }
